@@ -31,6 +31,10 @@ public class CanvasRE extends CanvasShape {
 	protected static String ARG_NAME_WIDTH_PIXELS = "width_pixels";
 	protected static String ARG_NAME_WIDTH_UNITS = "width_units";
 
+	protected CanvasRE(CanvasGroup group, int type) {
+		super(group, type);
+	}
+	
 	/**
 	 * Constructs an instance of CanvasRE from a native widget resource.
 	 * @param handle The handle to the native widget.
