@@ -17,6 +17,11 @@ import org.gnu.glib.Type;
  * rectangle on a GnomeCanvas.
  */
 public class CanvasRect extends CanvasRE {
+
+	public CanvasRect(CanvasGroup group) {
+		super(group, gnome_canvas_rect_get_type());
+	}
+	
 	/**
 	 * Constructs an instance of CanvasRect from a native widget resource.
 	 * @param handle The handle to the native widget.
@@ -40,15 +45,8 @@ public class CanvasRect extends CanvasRE {
 	 *                     zoom factor. 
 	 */
 	public CanvasRect(CanvasGroup group, double x1, double y1, double x2, double y2, Color fill_color, Color outline_color, Bitmap fill_stipple, Bitmap outline_stipple, int width_pixels) {
-		super(
-			gnome_canvas_re_new_gdk_wpix(
-				group.getHandle(),
-				gnome_canvas_rect_get_type(),
-				x1,
-				y1,
-				x2,
-				y2,
-				fill_color.getHandle(),
+		super(gnome_canvas_re_new_gdk_wpix(group.getHandle(), gnome_canvas_rect_get_type(),
+				x1, y1, x2, y2, fill_color.getHandle(),
 				outline_color == null ? 0 : outline_color.getHandle(),
 				fill_stipple == null ? 0 : fill_stipple.getHandle(),
 				outline_stipple == null ? 0 : outline_stipple.getHandle(),
@@ -69,15 +67,8 @@ public class CanvasRect extends CanvasRE {
 	 * @param width_units Outline width specified in Canvas units.
 	 */
 	public CanvasRect(CanvasGroup group, double x1, double y1, double x2, double y2, Color fill_color, Color outline_color, Bitmap fill_stipple, Bitmap outline_stipple, double width_units) {
-		super(
-			gnome_canvas_re_new_gdk_wunit(
-				group.getHandle(),
-				gnome_canvas_rect_get_type(),
-				x1,
-				y1,
-				x2,
-				y2,
-				fill_color.getHandle(),
+		super(gnome_canvas_re_new_gdk_wunit(group.getHandle(), gnome_canvas_rect_get_type(),
+				x1, y1, x2, y2, fill_color.getHandle(),
 				outline_color == null ? 0 : outline_color.getHandle(),
 				fill_stipple == null ? 0 : fill_stipple.getHandle(),
 				outline_stipple == null ? 0 : outline_stipple.getHandle(),
@@ -115,9 +106,6 @@ public class CanvasRect extends CanvasRE {
 		super(gnome_canvas_re_new_rgba_wunit(group.getHandle(), gnome_canvas_rect_get_type(), x1, y1, x2, y2, fill_color, outline_color, width_units));
 	}
 
-	protected void noopInit() {
-	}
-
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
