@@ -59,6 +59,10 @@ public class PasswordDialog extends Dialog {
 		return gnome_password_dialog_get_remember(getHandle());
 	}
 	
+	public void setShowUserpassButtons(boolean show) {
+		gnome_password_dialog_set_show_userpass_buttons(getHandle(), show);
+	}
+	
 	/****************************************
 	 * BEGINNING OF JNI CODE
 	 ****************************************/
@@ -69,6 +73,7 @@ public class PasswordDialog extends Dialog {
 	native static final protected void gnome_password_dialog_set_password(int dialog, String password);
 	native static final protected void gnome_password_dialog_set_readonly_username(int dialog, boolean readonly);
 	native static final protected void gnome_password_dialog_set_remember(int dialog, boolean remember);
+	native static final protected void gnome_password_dialog_set_show_userpass_buttons(int dialog, boolean show);
 	native static final protected String gnome_password_dialog_get_username(int dialog);
 	native static final protected String gnome_password_dialog_get_password(int dialog);
 	native static final protected boolean gnome_password_dialog_get_remember(int dialog);
